package eu.maiora.routes

import eu.maiora.model.ProdottiPrenotabiliRepositoryImpl
import eu.maiora.model.SlotOrariRepositoryImpl
import io.ktor.http.*
import io.ktor.server.application.*
import io.ktor.server.auth.*
import io.ktor.server.response.*
import io.ktor.server.routing.*


fun Route.prodottiPrenotabili(prodottiPrenotabiliRepository: ProdottiPrenotabiliRepositoryImpl){
    route("/api/prodottiPrenotabili"){
        authenticate("auth-jwt") {
            get(){
                // Ottieni l'id del turno, il giorno, l'id della modalita e l'id del punto di distribuzione dal percorso
                val idTurno = call.parameters["idTurno"]
                val giorno = call.parameters["giorno"]
                val idPuntoDistribuzione = call.parameters["idPuntoDistribuzione"]
                val idModalita = call.parameters["idModalita"]

                if (idTurno.isNullOrEmpty()) {
                    call.respondText("ID turno non valido o non presente nei parametri", status = HttpStatusCode.BadRequest)
                    return@get
                }
                if (idPuntoDistribuzione.isNullOrEmpty()) {
                    call.respondText("ID punto distribuzione non valido o non presente nei parametri", status = HttpStatusCode.BadRequest)
                    return@get
                }
                if (idModalita.isNullOrEmpty()) {
                    call.respondText("ID modalita non valido o non presente nei parametri", status = HttpStatusCode.BadRequest)
                    return@get
                }
                if (giorno.isNullOrEmpty()) {
                    call.respondText("Giorno non valido o non presente nei parametri", status = HttpStatusCode.BadRequest)
                    return@get
                }

                // Cerca i prodotti prenotabili per giorno, turno, punto distribuzione e modalita
                val listaProdottiPrenotabili = prodottiPrenotabiliRepository.prodottiPrenotabiliByGiornoIdTurnoIdPuntoDistIdMod(giorno,
                                                                                        idTurno.toLong(),
                                                                                        idPuntoDistribuzione.toLong(),
                                                                                        idModalita.toLong())


                if (listaProdottiPrenotabili != null) {
                    call.respond(listaProdottiPrenotabili)
                } else {
                    call.respondText("Prodotti prenotabili non trovati", status = HttpStatusCode.NotFound)
                }
            }
        }

    }
}