package eu.maiora.routes

import eu.maiora.model.TessereRepositoryImpl
import eu.maiora.model.ValorePasti
import eu.maiora.model.ValorePastiRepository
import io.ktor.http.*
import io.ktor.server.application.*
import io.ktor.server.auth.*
import io.ktor.server.response.*
import io.ktor.server.routing.*


fun Route.valorePasti(valorePastiRepository: ValorePastiRepository){
    route("/api/valorePasti"){
        authenticate("auth-jwt") {
            get(){
                // Ottieni i parametri dal percorso
                val idTessera = call.parameters["idTessera"]
                val idVassoio = call.parameters["idVassoio"]
                val data = call.parameters["data"]

                if (idTessera == null) {
                    call.respondText("ID tessera non valido", status = HttpStatusCode.BadRequest)
                    return@get
                }

                if (idVassoio == null) {
                    call.respondText("ID vassoio non valido", status = HttpStatusCode.BadRequest)
                    return@get
                }

                if (data == null) {
                    call.respondText("data non valida", status = HttpStatusCode.BadRequest)
                    return@get
                }

                // Cerca la tessera per codice fiscale
                val valorePasto = valorePastiRepository.valorePastoByTessVassData(idTessera, idVassoio, data)
                val prezzo = valorePasto.split("#").get(0)
                val punti = valorePasto.split("#").get(1)

                if(prezzo == "-1" && punti == "-1")
                    call.respondText("Prezzo e punti non trovati", status = HttpStatusCode.NotFound)


                call.respond( ValorePasti(idTessera.toLong(),
                                          idVassoio.toLong(), data,
                                          prezzo.replace(',', '.').toDouble(),
                                          punti.toInt()))
            }
        }

    }
}